# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"hello": "00-module.ipynb",
         "hi": "00-module.ipynb"}

modules = ["module.py"]

doc_url = "https://maxim_denisov.github.io/example_lib_name/"

git_url = "https://gitlab.com/templates184/nbs-to-pypi-pipeline"

def custom_doc_links(name): return None
